{ inputs, config, pkgs, ... }:
let
  microbin = pkgs.rustPlatform.buildRustPackage rec {
    pname = "microbin";
    version = "1.2.0";

    # GitHub sources do not have Cargo.lock
    src = pkgs.fetchCrate {
      inherit pname version;
      sha256 = "sha256-dZClslUTUchx+sOJzFG8wiAgyW/0RcCKfKYklKfVrzM=";
    };

    cargoSha256 = "sha256-fBbChu5iy/2H/8IYCwd1OwxplGPZAmkd8z8xD7Uc0vo=";
  };
in {
  environment.systemPackages = with pkgs; [ microbin ];
  systemd.services.microbin = {
    after = [ "network.target" ];
    wantedBy = [ "multi-user.target" ];
    environment = {
      MICROBIN_AUTH_USERNAME = "jade";
      MICROBIN_AUTH_PASSWORD = builtins.readFile ../secret-data/mb-pass;
      MICROBIN_HASH_IDS = "";
      MICROBIN_EDITABLE = "";
      MICROBIN_PRIVATE = "";
      MICROBIN_HIGHLIGHTSYNTAX = "";
      MICROBIN_PUBLIC_PATH = "https://s10e.de";
      MICROBIN_QR = "";
    };
    script = "${pkgs.microbin}/bin/microbin";
    #scriptArgs = "--auth-password ${builtins.readFile ../secret-data/mb-pass} --auth-username jade --editable --hash-ids --no-listing --highlightsyntax --public-path https://s10e.de --qr";
    serviceConfig = {
      Type = "simple";
      RootDirectory="/";
      WorkingDirectory = "/microbin";
    };
  };
}
